================
 Invenio v3.0.0
================

Invenio v3.0.0 was released on November 9, 2015.

About
-----

Invenio is a digital library framework enabling you to build your own digital
library or document repository on the web.

What's new
----------

Installation
------------

   $ pip install invenio==3.0.0

Documentation
-------------

   http://pythonhosted.org/invenio/

Happy hacking and thanks for flying Invenio.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio
|   URL: http://invenio-software.org
